;; Generated package description from gnugo.el  -*- no-byte-compile: t -*-
(define-package "gnugo" "3.1.2.0.20250131.151403" "play GNU Go in a buffer" '((ascii-art-to-unicode "1.5") (xpm "1.0.1") (cl-lib "0.5")) :commit "2b696d4e2256e64064e1b87903c4e4b2b382156d" :authors '(("Thien-Thi Nguyen" . "ttn@gnu.org")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("games" "processes") :url "https://www.gnuvola.org/software/gnugo/")
